Get Day and time of the year as a POSIX
dayte_time.RdReturns the day of the year as a Date by setting the year to be 1972 (as a leap year with two leap seconds)
Examples
dayte_time(as.POSIXct("2001-05-16 02:03:04"))
#> [1] "1972-05-16 02:03:04 UTC"
dayte_time.RdReturns the day of the year as a Date by setting the year to be 1972 (as a leap year with two leap seconds)
dayte_time(as.POSIXct("2001-05-16 02:03:04"))
#> [1] "1972-05-16 02:03:04 UTC"